utils::globalVariables(c(
  ".", ":=",
  "n", "true_effect", "ok", "pass", "assurance",
  "post_prob_direction", "post_prob_threshold", "post_prob_rope",
  "power_direction", "power_threshold", "power_rope",
  "avg_ci_width", "ci_coverage",
  "ciw_q05", "ciw_q25", "ciw_q50", "ciw_q75", "ciw_q95",
  "avg_post_prob_direction", "avg_post_prob_threshold", "avg_post_prob_rope",
  "bf10", "bf_hit_3", "bf_hit_10", "log10_bf10", "mean_log10_bf", "nsims_ok",
  "scenario", "ymin", "ymax", "ymid", "p_star",
  "q05", "q25", "q50", "q75", "q95", "ci_width",
  "mean_", "sd_","hit", "hits", "trials", "lo", "hi", "sim", "n", "treatment", "age_effect",
  "._ok_all","n_recommended","value"
))